.. Copyright 2013-2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Web framework
=============

.. toctree::
   :maxdepth: 2

   Core web framework functionality (reahl.web.fw) <fw>
   Widgets -- user interface elements (reahl.web.ui) <ui>
   Widgets and other classes that help with layout (reahl.web.layout) <layout>
   Widgets and Layouts (bootstrap) -- bootstrap-styled Widgets and Layouts (reahl.web.bootstrap) <bootstrap/index>
   Holder -- on-the-fly placeholder images (reahl.web.holder) <holder>

   Layout using Pure (reahl.web.pure) <pure>
   Paging long lists (reahl.web.pager) <pager>
   Tables with multiple pages (reahl.web.datatable) <datatable>
   Including not-quite-static static content (reahl.web.dhtml) <dhtml>
   Interfaces for persisted classes of which many implementations can exist (reahl.web.interfaces) <interfaces>
   The declarative implementation (reahl.webdeclarative) <webdeclarative>

   Dealing with JavaScript and CSS code and external libraries (reahl.web.libraries) <libraries>


